@@ -4,7 +4,12 @@ from .categorical_categorical import (
     mat_fisher_naive,
     mat_fisher_nan,
 )
-from .continuous_categorical import mat_mwu, mat_mwu_gpu, mat_mwu_naive
+from .continuous_categorical import (
+    biserial_continuous_nan,
+    mat_mwu,
+    mat_mwu_gpu,
+    mat_mwu_naive,
+)
 from .continuous_continuous import (
     mat_corr,
     mat_corr_naive,
@@ -12,10 +17,10 @@ from .continuous_continuous import (
     mat_corr_subtyped,
 )
 from .continuous_continuous_cmap import (
-    fast_cov,
-    nan_fast_cov,
     fast_corr,
-    nan_fast_corr,
+    fast_cov,
     fast_spearman,
+    nan_fast_corr,
+    nan_fast_cov,
     nan_fast_spearman,
 )
